==> haskell-configfile-1.1.4-41-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-configfile.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ConfigFile
version: 1.1.4
id: ConfigFile-1.1.4-KyeVWL1kaO13dFcUNLEMGU
key: ConfigFile-1.1.4-KyeVWL1kaO13dFcUNLEMGU
license: BSD-3-Clause
copyright: Copyright (c) 2004-2014 John Goerzen
maintainer: John Goerzen <jgoerzen@complete.org>
author: John Goerzen
stability: Stable
homepage: http://software.complete.org/configfile
synopsis: Configuration file reading & writing
description:
    Parser and writer for handling sectioned config files in
    Haskell.
    .
    The ConfigFile module works with configuration files in a standard
    format that is easy for the user to edit, easy for the programmer
    to work with, yet remains powerful and flexible.  It is inspired by,
    and compatible with, Python'\''s ConfigParser module.  It uses files
    that resemble Windows .INI-style files, but with numerous
    improvements.
    .
    ConfigFile provides simple calls to both read and write config files.
    It'\''s possible to make a config file parsable by this module,
    the Unix shell, and make.
category: Parsing
abi: ce1ba7423afb779de5048e4a394cf889
exposed: True
exposed-modules:
    Data.ConfigFile Data.ConfigFile.Monadic Data.ConfigFile.Parser
    Data.ConfigFile.Types
hidden-modules: Data.ConfigFile.Lexer
import-dirs: /usr/lib/ghc-8.4.3/site-local/ConfigFile-1.1.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/ConfigFile-1.1.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/ConfigFile-1.1.4
hs-libraries: HSConfigFile-1.1.4-KyeVWL1kaO13dFcUNLEMGU
depends:
    MissingH-1.4.1.0-ERaselimISKLNZyWwaT7XP base-4.11.1.0
    containers-0.5.11.0 mtl-2.2.2 parsec-3.1.13.0
abi-depends: MissingH-1.4.1.0-ERaselimISKLNZyWwaT7XP=2eeb75167347837b2e3f8f24db08cc54
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             parsec-3.1.13.0=3626e7cedd22de76a8b10339d955721a
haddock-interfaces: /usr/share/doc/haskell-configfile/html/ConfigFile.haddock
haddock-html: /usr/share/doc/haskell-configfile/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-configfile-1.1.4-43-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-configfile.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ConfigFile
version: 1.1.4
id: ConfigFile-1.1.4-B8KB7yJPbsGB6KURBM5dr5
key: ConfigFile-1.1.4-B8KB7yJPbsGB6KURBM5dr5
license: BSD-3-Clause
copyright: Copyright (c) 2004-2014 John Goerzen
maintainer: John Goerzen <jgoerzen@complete.org>
author: John Goerzen
stability: Stable
homepage: http://software.complete.org/configfile
synopsis: Configuration file reading & writing
description:
    Parser and writer for handling sectioned config files in
    Haskell.
    .
    The ConfigFile module works with configuration files in a standard
    format that is easy for the user to edit, easy for the programmer
    to work with, yet remains powerful and flexible.  It is inspired by,
    and compatible with, Python'\''s ConfigParser module.  It uses files
    that resemble Windows .INI-style files, but with numerous
    improvements.
    .
    ConfigFile provides simple calls to both read and write config files.
    It'\''s possible to make a config file parsable by this module,
    the Unix shell, and make.
category: Parsing
abi: 6f542f3a730f567cb4a9e30c6139ed2c
exposed: True
exposed-modules:
    Data.ConfigFile Data.ConfigFile.Monadic Data.ConfigFile.Parser
    Data.ConfigFile.Types
hidden-modules: Data.ConfigFile.Lexer
import-dirs: /usr/lib/ghc-8.6.1/site-local/ConfigFile-1.1.4
library-dirs: /usr/lib/ghc-8.6.1/site-local/ConfigFile-1.1.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/ConfigFile-1.1.4
hs-libraries: HSConfigFile-1.1.4-B8KB7yJPbsGB6KURBM5dr5
depends:
    MissingH-1.4.1.0-HTvcmoLSVIMFeImwD3Fcve base-4.12.0.0
    containers-0.6.0.1 mtl-2.2.2 parsec-3.1.13.0
haddock-interfaces: /usr/share/doc/haskell-configfile/html/ConfigFile.haddock
haddock-html: /usr/share/doc/haskell-configfile/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
